# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateWebAppFirewallPolicyDetails(object):
    """
    The information about new WebAppFirewallPolicy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateWebAppFirewallPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateWebAppFirewallPolicyDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateWebAppFirewallPolicyDetails.
        :type compartment_id: str

        :param actions:
            The value to assign to the actions property of this CreateWebAppFirewallPolicyDetails.
        :type actions: list[oci.waf.models.Action]

        :param request_access_control:
            The value to assign to the request_access_control property of this CreateWebAppFirewallPolicyDetails.
        :type request_access_control: oci.waf.models.RequestAccessControl

        :param request_rate_limiting:
            The value to assign to the request_rate_limiting property of this CreateWebAppFirewallPolicyDetails.
        :type request_rate_limiting: oci.waf.models.RequestRateLimiting

        :param request_protection:
            The value to assign to the request_protection property of this CreateWebAppFirewallPolicyDetails.
        :type request_protection: oci.waf.models.RequestProtection

        :param response_access_control:
            The value to assign to the response_access_control property of this CreateWebAppFirewallPolicyDetails.
        :type response_access_control: oci.waf.models.ResponseAccessControl

        :param response_protection:
            The value to assign to the response_protection property of this CreateWebAppFirewallPolicyDetails.
        :type response_protection: oci.waf.models.ResponseProtection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateWebAppFirewallPolicyDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateWebAppFirewallPolicyDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this CreateWebAppFirewallPolicyDetails.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'actions': 'list[Action]',
            'request_access_control': 'RequestAccessControl',
            'request_rate_limiting': 'RequestRateLimiting',
            'request_protection': 'RequestProtection',
            'response_access_control': 'ResponseAccessControl',
            'response_protection': 'ResponseProtection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'actions': 'actions',
            'request_access_control': 'requestAccessControl',
            'request_rate_limiting': 'requestRateLimiting',
            'request_protection': 'requestProtection',
            'response_access_control': 'responseAccessControl',
            'response_protection': 'responseProtection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._actions = None
        self._request_access_control = None
        self._request_rate_limiting = None
        self._request_protection = None
        self._response_access_control = None
        self._response_protection = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateWebAppFirewallPolicyDetails.
        WebAppFirewallPolicy display name, can be renamed.


        :return: The display_name of this CreateWebAppFirewallPolicyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateWebAppFirewallPolicyDetails.
        WebAppFirewallPolicy display name, can be renamed.


        :param display_name: The display_name of this CreateWebAppFirewallPolicyDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateWebAppFirewallPolicyDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateWebAppFirewallPolicyDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateWebAppFirewallPolicyDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateWebAppFirewallPolicyDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def actions(self):
        """
        Gets the actions of this CreateWebAppFirewallPolicyDetails.
        Predefined actions for use in multiple different rules. Not all actions are supported in every module.
        Some actions terminate further execution of modules and rules in a module and some do not.
        Actions names must be unique within this array.


        :return: The actions of this CreateWebAppFirewallPolicyDetails.
        :rtype: list[oci.waf.models.Action]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this CreateWebAppFirewallPolicyDetails.
        Predefined actions for use in multiple different rules. Not all actions are supported in every module.
        Some actions terminate further execution of modules and rules in a module and some do not.
        Actions names must be unique within this array.


        :param actions: The actions of this CreateWebAppFirewallPolicyDetails.
        :type: list[oci.waf.models.Action]
        """
        self._actions = actions

    @property
    def request_access_control(self):
        """
        Gets the request_access_control of this CreateWebAppFirewallPolicyDetails.

        :return: The request_access_control of this CreateWebAppFirewallPolicyDetails.
        :rtype: oci.waf.models.RequestAccessControl
        """
        return self._request_access_control

    @request_access_control.setter
    def request_access_control(self, request_access_control):
        """
        Sets the request_access_control of this CreateWebAppFirewallPolicyDetails.

        :param request_access_control: The request_access_control of this CreateWebAppFirewallPolicyDetails.
        :type: oci.waf.models.RequestAccessControl
        """
        self._request_access_control = request_access_control

    @property
    def request_rate_limiting(self):
        """
        Gets the request_rate_limiting of this CreateWebAppFirewallPolicyDetails.

        :return: The request_rate_limiting of this CreateWebAppFirewallPolicyDetails.
        :rtype: oci.waf.models.RequestRateLimiting
        """
        return self._request_rate_limiting

    @request_rate_limiting.setter
    def request_rate_limiting(self, request_rate_limiting):
        """
        Sets the request_rate_limiting of this CreateWebAppFirewallPolicyDetails.

        :param request_rate_limiting: The request_rate_limiting of this CreateWebAppFirewallPolicyDetails.
        :type: oci.waf.models.RequestRateLimiting
        """
        self._request_rate_limiting = request_rate_limiting

    @property
    def request_protection(self):
        """
        Gets the request_protection of this CreateWebAppFirewallPolicyDetails.

        :return: The request_protection of this CreateWebAppFirewallPolicyDetails.
        :rtype: oci.waf.models.RequestProtection
        """
        return self._request_protection

    @request_protection.setter
    def request_protection(self, request_protection):
        """
        Sets the request_protection of this CreateWebAppFirewallPolicyDetails.

        :param request_protection: The request_protection of this CreateWebAppFirewallPolicyDetails.
        :type: oci.waf.models.RequestProtection
        """
        self._request_protection = request_protection

    @property
    def response_access_control(self):
        """
        Gets the response_access_control of this CreateWebAppFirewallPolicyDetails.

        :return: The response_access_control of this CreateWebAppFirewallPolicyDetails.
        :rtype: oci.waf.models.ResponseAccessControl
        """
        return self._response_access_control

    @response_access_control.setter
    def response_access_control(self, response_access_control):
        """
        Sets the response_access_control of this CreateWebAppFirewallPolicyDetails.

        :param response_access_control: The response_access_control of this CreateWebAppFirewallPolicyDetails.
        :type: oci.waf.models.ResponseAccessControl
        """
        self._response_access_control = response_access_control

    @property
    def response_protection(self):
        """
        Gets the response_protection of this CreateWebAppFirewallPolicyDetails.

        :return: The response_protection of this CreateWebAppFirewallPolicyDetails.
        :rtype: oci.waf.models.ResponseProtection
        """
        return self._response_protection

    @response_protection.setter
    def response_protection(self, response_protection):
        """
        Sets the response_protection of this CreateWebAppFirewallPolicyDetails.

        :param response_protection: The response_protection of this CreateWebAppFirewallPolicyDetails.
        :type: oci.waf.models.ResponseProtection
        """
        self._response_protection = response_protection

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateWebAppFirewallPolicyDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateWebAppFirewallPolicyDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateWebAppFirewallPolicyDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateWebAppFirewallPolicyDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateWebAppFirewallPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateWebAppFirewallPolicyDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateWebAppFirewallPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateWebAppFirewallPolicyDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this CreateWebAppFirewallPolicyDetails.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this CreateWebAppFirewallPolicyDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this CreateWebAppFirewallPolicyDetails.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this CreateWebAppFirewallPolicyDetails.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NodePoolNodeConfigDetails(object):
    """
    The size and placement configuration of nodes in the node pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NodePoolNodeConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param size:
            The value to assign to the size property of this NodePoolNodeConfigDetails.
        :type size: int

        :param nsg_ids:
            The value to assign to the nsg_ids property of this NodePoolNodeConfigDetails.
        :type nsg_ids: list[str]

        :param kms_key_id:
            The value to assign to the kms_key_id property of this NodePoolNodeConfigDetails.
        :type kms_key_id: str

        :param is_pv_encryption_in_transit_enabled:
            The value to assign to the is_pv_encryption_in_transit_enabled property of this NodePoolNodeConfigDetails.
        :type is_pv_encryption_in_transit_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this NodePoolNodeConfigDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this NodePoolNodeConfigDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param placement_configs:
            The value to assign to the placement_configs property of this NodePoolNodeConfigDetails.
        :type placement_configs: list[oci.container_engine.models.NodePoolPlacementConfigDetails]

        :param node_pool_pod_network_option_details:
            The value to assign to the node_pool_pod_network_option_details property of this NodePoolNodeConfigDetails.
        :type node_pool_pod_network_option_details: oci.container_engine.models.NodePoolPodNetworkOptionDetails

        """
        self.swagger_types = {
            'size': 'int',
            'nsg_ids': 'list[str]',
            'kms_key_id': 'str',
            'is_pv_encryption_in_transit_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'placement_configs': 'list[NodePoolPlacementConfigDetails]',
            'node_pool_pod_network_option_details': 'NodePoolPodNetworkOptionDetails'
        }

        self.attribute_map = {
            'size': 'size',
            'nsg_ids': 'nsgIds',
            'kms_key_id': 'kmsKeyId',
            'is_pv_encryption_in_transit_enabled': 'isPvEncryptionInTransitEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'placement_configs': 'placementConfigs',
            'node_pool_pod_network_option_details': 'nodePoolPodNetworkOptionDetails'
        }

        self._size = None
        self._nsg_ids = None
        self._kms_key_id = None
        self._is_pv_encryption_in_transit_enabled = None
        self._freeform_tags = None
        self._defined_tags = None
        self._placement_configs = None
        self._node_pool_pod_network_option_details = None

    @property
    def size(self):
        """
        Gets the size of this NodePoolNodeConfigDetails.
        The number of nodes in the node pool.


        :return: The size of this NodePoolNodeConfigDetails.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this NodePoolNodeConfigDetails.
        The number of nodes in the node pool.


        :param size: The size of this NodePoolNodeConfigDetails.
        :type: int
        """
        self._size = size

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this NodePoolNodeConfigDetails.
        The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see :class:`NetworkSecurityGroup`.


        :return: The nsg_ids of this NodePoolNodeConfigDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this NodePoolNodeConfigDetails.
        The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see :class:`NetworkSecurityGroup`.


        :param nsg_ids: The nsg_ids of this NodePoolNodeConfigDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this NodePoolNodeConfigDetails.
        The OCID of the Key Management Service key assigned to the boot volume.


        :return: The kms_key_id of this NodePoolNodeConfigDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this NodePoolNodeConfigDetails.
        The OCID of the Key Management Service key assigned to the boot volume.


        :param kms_key_id: The kms_key_id of this NodePoolNodeConfigDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def is_pv_encryption_in_transit_enabled(self):
        """
        Gets the is_pv_encryption_in_transit_enabled of this NodePoolNodeConfigDetails.
        Whether to enable in-transit encryption for the data volume's paravirtualized attachment. This field applies to both block volumes and boot volumes. The default value is false.


        :return: The is_pv_encryption_in_transit_enabled of this NodePoolNodeConfigDetails.
        :rtype: bool
        """
        return self._is_pv_encryption_in_transit_enabled

    @is_pv_encryption_in_transit_enabled.setter
    def is_pv_encryption_in_transit_enabled(self, is_pv_encryption_in_transit_enabled):
        """
        Sets the is_pv_encryption_in_transit_enabled of this NodePoolNodeConfigDetails.
        Whether to enable in-transit encryption for the data volume's paravirtualized attachment. This field applies to both block volumes and boot volumes. The default value is false.


        :param is_pv_encryption_in_transit_enabled: The is_pv_encryption_in_transit_enabled of this NodePoolNodeConfigDetails.
        :type: bool
        """
        self._is_pv_encryption_in_transit_enabled = is_pv_encryption_in_transit_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this NodePoolNodeConfigDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this NodePoolNodeConfigDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this NodePoolNodeConfigDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this NodePoolNodeConfigDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this NodePoolNodeConfigDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this NodePoolNodeConfigDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this NodePoolNodeConfigDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this NodePoolNodeConfigDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def placement_configs(self):
        """
        Gets the placement_configs of this NodePoolNodeConfigDetails.
        The placement configurations for the node pool. Provide one placement
        configuration for each availability domain in which you intend to launch a node.

        To use the node pool with a regional subnet, provide a placement configuration for
        each availability domain, and include the regional subnet in each placement
        configuration.


        :return: The placement_configs of this NodePoolNodeConfigDetails.
        :rtype: list[oci.container_engine.models.NodePoolPlacementConfigDetails]
        """
        return self._placement_configs

    @placement_configs.setter
    def placement_configs(self, placement_configs):
        """
        Sets the placement_configs of this NodePoolNodeConfigDetails.
        The placement configurations for the node pool. Provide one placement
        configuration for each availability domain in which you intend to launch a node.

        To use the node pool with a regional subnet, provide a placement configuration for
        each availability domain, and include the regional subnet in each placement
        configuration.


        :param placement_configs: The placement_configs of this NodePoolNodeConfigDetails.
        :type: list[oci.container_engine.models.NodePoolPlacementConfigDetails]
        """
        self._placement_configs = placement_configs

    @property
    def node_pool_pod_network_option_details(self):
        """
        Gets the node_pool_pod_network_option_details of this NodePoolNodeConfigDetails.
        The CNI related configuration of pods in the node pool.


        :return: The node_pool_pod_network_option_details of this NodePoolNodeConfigDetails.
        :rtype: oci.container_engine.models.NodePoolPodNetworkOptionDetails
        """
        return self._node_pool_pod_network_option_details

    @node_pool_pod_network_option_details.setter
    def node_pool_pod_network_option_details(self, node_pool_pod_network_option_details):
        """
        Sets the node_pool_pod_network_option_details of this NodePoolNodeConfigDetails.
        The CNI related configuration of pods in the node pool.


        :param node_pool_pod_network_option_details: The node_pool_pod_network_option_details of this NodePoolNodeConfigDetails.
        :type: oci.container_engine.models.NodePoolPodNetworkOptionDetails
        """
        self._node_pool_pod_network_option_details = node_pool_pod_network_option_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deploy_stage_summary import DeployStageSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OkeHelmChartDeployStageSummary(DeployStageSummary):
    """
    Specifies the OKE cluster deployment stage using Helm charts.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OkeHelmChartDeployStageSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.OkeHelmChartDeployStageSummary.deploy_stage_type` attribute
        of this class is ``OKE_HELM_CHART_DEPLOYMENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OkeHelmChartDeployStageSummary.
        :type id: str

        :param description:
            The value to assign to the description property of this OkeHelmChartDeployStageSummary.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this OkeHelmChartDeployStageSummary.
        :type display_name: str

        :param project_id:
            The value to assign to the project_id property of this OkeHelmChartDeployStageSummary.
        :type project_id: str

        :param deploy_pipeline_id:
            The value to assign to the deploy_pipeline_id property of this OkeHelmChartDeployStageSummary.
        :type deploy_pipeline_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OkeHelmChartDeployStageSummary.
        :type compartment_id: str

        :param deploy_stage_type:
            The value to assign to the deploy_stage_type property of this OkeHelmChartDeployStageSummary.
        :type deploy_stage_type: str

        :param time_created:
            The value to assign to the time_created property of this OkeHelmChartDeployStageSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this OkeHelmChartDeployStageSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OkeHelmChartDeployStageSummary.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this OkeHelmChartDeployStageSummary.
        :type lifecycle_details: str

        :param deploy_stage_predecessor_collection:
            The value to assign to the deploy_stage_predecessor_collection property of this OkeHelmChartDeployStageSummary.
        :type deploy_stage_predecessor_collection: oci.devops.models.DeployStagePredecessorCollection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OkeHelmChartDeployStageSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OkeHelmChartDeployStageSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this OkeHelmChartDeployStageSummary.
        :type system_tags: dict(str, dict(str, object))

        :param oke_cluster_deploy_environment_id:
            The value to assign to the oke_cluster_deploy_environment_id property of this OkeHelmChartDeployStageSummary.
        :type oke_cluster_deploy_environment_id: str

        :param helm_chart_deploy_artifact_id:
            The value to assign to the helm_chart_deploy_artifact_id property of this OkeHelmChartDeployStageSummary.
        :type helm_chart_deploy_artifact_id: str

        :param values_artifact_ids:
            The value to assign to the values_artifact_ids property of this OkeHelmChartDeployStageSummary.
        :type values_artifact_ids: list[str]

        :param release_name:
            The value to assign to the release_name property of this OkeHelmChartDeployStageSummary.
        :type release_name: str

        :param namespace:
            The value to assign to the namespace property of this OkeHelmChartDeployStageSummary.
        :type namespace: str

        :param timeout_in_seconds:
            The value to assign to the timeout_in_seconds property of this OkeHelmChartDeployStageSummary.
        :type timeout_in_seconds: int

        :param rollback_policy:
            The value to assign to the rollback_policy property of this OkeHelmChartDeployStageSummary.
        :type rollback_policy: oci.devops.models.DeployStageRollbackPolicy

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'display_name': 'str',
            'project_id': 'str',
            'deploy_pipeline_id': 'str',
            'compartment_id': 'str',
            'deploy_stage_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'deploy_stage_predecessor_collection': 'DeployStagePredecessorCollection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'oke_cluster_deploy_environment_id': 'str',
            'helm_chart_deploy_artifact_id': 'str',
            'values_artifact_ids': 'list[str]',
            'release_name': 'str',
            'namespace': 'str',
            'timeout_in_seconds': 'int',
            'rollback_policy': 'DeployStageRollbackPolicy'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'display_name': 'displayName',
            'project_id': 'projectId',
            'deploy_pipeline_id': 'deployPipelineId',
            'compartment_id': 'compartmentId',
            'deploy_stage_type': 'deployStageType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'deploy_stage_predecessor_collection': 'deployStagePredecessorCollection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'oke_cluster_deploy_environment_id': 'okeClusterDeployEnvironmentId',
            'helm_chart_deploy_artifact_id': 'helmChartDeployArtifactId',
            'values_artifact_ids': 'valuesArtifactIds',
            'release_name': 'releaseName',
            'namespace': 'namespace',
            'timeout_in_seconds': 'timeoutInSeconds',
            'rollback_policy': 'rollbackPolicy'
        }

        self._id = None
        self._description = None
        self._display_name = None
        self._project_id = None
        self._deploy_pipeline_id = None
        self._compartment_id = None
        self._deploy_stage_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._deploy_stage_predecessor_collection = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._oke_cluster_deploy_environment_id = None
        self._helm_chart_deploy_artifact_id = None
        self._values_artifact_ids = None
        self._release_name = None
        self._namespace = None
        self._timeout_in_seconds = None
        self._rollback_policy = None
        self._deploy_stage_type = 'OKE_HELM_CHART_DEPLOYMENT'

    @property
    def oke_cluster_deploy_environment_id(self):
        """
        **[Required]** Gets the oke_cluster_deploy_environment_id of this OkeHelmChartDeployStageSummary.
        Kubernetes cluster environment OCID for deployment.


        :return: The oke_cluster_deploy_environment_id of this OkeHelmChartDeployStageSummary.
        :rtype: str
        """
        return self._oke_cluster_deploy_environment_id

    @oke_cluster_deploy_environment_id.setter
    def oke_cluster_deploy_environment_id(self, oke_cluster_deploy_environment_id):
        """
        Sets the oke_cluster_deploy_environment_id of this OkeHelmChartDeployStageSummary.
        Kubernetes cluster environment OCID for deployment.


        :param oke_cluster_deploy_environment_id: The oke_cluster_deploy_environment_id of this OkeHelmChartDeployStageSummary.
        :type: str
        """
        self._oke_cluster_deploy_environment_id = oke_cluster_deploy_environment_id

    @property
    def helm_chart_deploy_artifact_id(self):
        """
        **[Required]** Gets the helm_chart_deploy_artifact_id of this OkeHelmChartDeployStageSummary.
        Helm chart artifact OCID.


        :return: The helm_chart_deploy_artifact_id of this OkeHelmChartDeployStageSummary.
        :rtype: str
        """
        return self._helm_chart_deploy_artifact_id

    @helm_chart_deploy_artifact_id.setter
    def helm_chart_deploy_artifact_id(self, helm_chart_deploy_artifact_id):
        """
        Sets the helm_chart_deploy_artifact_id of this OkeHelmChartDeployStageSummary.
        Helm chart artifact OCID.


        :param helm_chart_deploy_artifact_id: The helm_chart_deploy_artifact_id of this OkeHelmChartDeployStageSummary.
        :type: str
        """
        self._helm_chart_deploy_artifact_id = helm_chart_deploy_artifact_id

    @property
    def values_artifact_ids(self):
        """
        Gets the values_artifact_ids of this OkeHelmChartDeployStageSummary.
        List of values.yaml file artifact OCIDs.


        :return: The values_artifact_ids of this OkeHelmChartDeployStageSummary.
        :rtype: list[str]
        """
        return self._values_artifact_ids

    @values_artifact_ids.setter
    def values_artifact_ids(self, values_artifact_ids):
        """
        Sets the values_artifact_ids of this OkeHelmChartDeployStageSummary.
        List of values.yaml file artifact OCIDs.


        :param values_artifact_ids: The values_artifact_ids of this OkeHelmChartDeployStageSummary.
        :type: list[str]
        """
        self._values_artifact_ids = values_artifact_ids

    @property
    def release_name(self):
        """
        **[Required]** Gets the release_name of this OkeHelmChartDeployStageSummary.
        Release name of the Helm chart.


        :return: The release_name of this OkeHelmChartDeployStageSummary.
        :rtype: str
        """
        return self._release_name

    @release_name.setter
    def release_name(self, release_name):
        """
        Sets the release_name of this OkeHelmChartDeployStageSummary.
        Release name of the Helm chart.


        :param release_name: The release_name of this OkeHelmChartDeployStageSummary.
        :type: str
        """
        self._release_name = release_name

    @property
    def namespace(self):
        """
        Gets the namespace of this OkeHelmChartDeployStageSummary.
        Default namespace to be used for Kubernetes deployment when not specified in the manifest.


        :return: The namespace of this OkeHelmChartDeployStageSummary.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this OkeHelmChartDeployStageSummary.
        Default namespace to be used for Kubernetes deployment when not specified in the manifest.


        :param namespace: The namespace of this OkeHelmChartDeployStageSummary.
        :type: str
        """
        self._namespace = namespace

    @property
    def timeout_in_seconds(self):
        """
        Gets the timeout_in_seconds of this OkeHelmChartDeployStageSummary.
        Time to wait for execution of a helm stage. Defaults to 300 seconds.


        :return: The timeout_in_seconds of this OkeHelmChartDeployStageSummary.
        :rtype: int
        """
        return self._timeout_in_seconds

    @timeout_in_seconds.setter
    def timeout_in_seconds(self, timeout_in_seconds):
        """
        Sets the timeout_in_seconds of this OkeHelmChartDeployStageSummary.
        Time to wait for execution of a helm stage. Defaults to 300 seconds.


        :param timeout_in_seconds: The timeout_in_seconds of this OkeHelmChartDeployStageSummary.
        :type: int
        """
        self._timeout_in_seconds = timeout_in_seconds

    @property
    def rollback_policy(self):
        """
        Gets the rollback_policy of this OkeHelmChartDeployStageSummary.

        :return: The rollback_policy of this OkeHelmChartDeployStageSummary.
        :rtype: oci.devops.models.DeployStageRollbackPolicy
        """
        return self._rollback_policy

    @rollback_policy.setter
    def rollback_policy(self, rollback_policy):
        """
        Sets the rollback_policy of this OkeHelmChartDeployStageSummary.

        :param rollback_policy: The rollback_policy of this OkeHelmChartDeployStageSummary.
        :type: oci.devops.models.DeployStageRollbackPolicy
        """
        self._rollback_policy = rollback_policy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateScopedAccessTokenDetails(object):
    """
    GenerateScopedAccessTokenDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateScopedAccessTokenDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param scope:
            The value to assign to the scope property of this GenerateScopedAccessTokenDetails.
        :type scope: str

        :param public_key:
            The value to assign to the public_key property of this GenerateScopedAccessTokenDetails.
        :type public_key: str

        """
        self.swagger_types = {
            'scope': 'str',
            'public_key': 'str'
        }

        self.attribute_map = {
            'scope': 'scope',
            'public_key': 'publicKey'
        }

        self._scope = None
        self._public_key = None

    @property
    def scope(self):
        """
        **[Required]** Gets the scope of this GenerateScopedAccessTokenDetails.
        Scope definition for the scoped access token


        :return: The scope of this GenerateScopedAccessTokenDetails.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this GenerateScopedAccessTokenDetails.
        Scope definition for the scoped access token


        :param scope: The scope of this GenerateScopedAccessTokenDetails.
        :type: str
        """
        self._scope = scope

    @property
    def public_key(self):
        """
        **[Required]** Gets the public_key of this GenerateScopedAccessTokenDetails.
        A temporary public key, owned by the service. The service also owns the corresponding private key. This public
        key will by put inside the security token by the auth service after successful validation of the certificate.


        :return: The public_key of this GenerateScopedAccessTokenDetails.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this GenerateScopedAccessTokenDetails.
        A temporary public key, owned by the service. The service also owns the corresponding private key. This public
        key will by put inside the security token by the auth service after successful validation of the certificate.


        :param public_key: The public_key of this GenerateScopedAccessTokenDetails.
        :type: str
        """
        self._public_key = public_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_entity_shape_details import CreateEntityShapeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateEntityShapeFromDataStore(CreateEntityShapeDetails):
    """
    The data store entity details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateEntityShapeFromDataStore object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.CreateEntityShapeFromDataStore.model_type` attribute
        of this class is ``DATA_STORE_ENTITY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateEntityShapeFromDataStore.
            Allowed values for this property are: "VIEW_ENTITY", "TABLE_ENTITY", "FILE_ENTITY", "DATA_STORE_ENTITY", "SQL_ENTITY"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateEntityShapeFromDataStore.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateEntityShapeFromDataStore.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this CreateEntityShapeFromDataStore.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this CreateEntityShapeFromDataStore.
        :type name: str

        :param object_version:
            The value to assign to the object_version property of this CreateEntityShapeFromDataStore.
        :type object_version: int

        :param external_key:
            The value to assign to the external_key property of this CreateEntityShapeFromDataStore.
        :type external_key: str

        :param shape:
            The value to assign to the shape property of this CreateEntityShapeFromDataStore.
        :type shape: oci.data_connectivity.models.Shape

        :param shape_id:
            The value to assign to the shape_id property of this CreateEntityShapeFromDataStore.
        :type shape_id: str

        :param entity_type:
            The value to assign to the entity_type property of this CreateEntityShapeFromDataStore.
            Allowed values for this property are: "TABLE", "VIEW", "FILE", "SQL"
        :type entity_type: str

        :param other_type_label:
            The value to assign to the other_type_label property of this CreateEntityShapeFromDataStore.
        :type other_type_label: str

        :param unique_keys:
            The value to assign to the unique_keys property of this CreateEntityShapeFromDataStore.
        :type unique_keys: list[oci.data_connectivity.models.UniqueKey]

        :param foreign_keys:
            The value to assign to the foreign_keys property of this CreateEntityShapeFromDataStore.
        :type foreign_keys: list[oci.data_connectivity.models.ForeignKey]

        :param resource_name:
            The value to assign to the resource_name property of this CreateEntityShapeFromDataStore.
        :type resource_name: str

        :param object_status:
            The value to assign to the object_status property of this CreateEntityShapeFromDataStore.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateEntityShapeFromDataStore.
        :type identifier: str

        :param types:
            The value to assign to the types property of this CreateEntityShapeFromDataStore.
        :type types: oci.data_connectivity.models.TypeLibrary

        :param entity_properties:
            The value to assign to the entity_properties property of this CreateEntityShapeFromDataStore.
        :type entity_properties: dict(str, str)

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'object_version': 'int',
            'external_key': 'str',
            'shape': 'Shape',
            'shape_id': 'str',
            'entity_type': 'str',
            'other_type_label': 'str',
            'unique_keys': 'list[UniqueKey]',
            'foreign_keys': 'list[ForeignKey]',
            'resource_name': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'types': 'TypeLibrary',
            'entity_properties': 'dict(str, str)'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'object_version': 'objectVersion',
            'external_key': 'externalKey',
            'shape': 'shape',
            'shape_id': 'shapeId',
            'entity_type': 'entityType',
            'other_type_label': 'otherTypeLabel',
            'unique_keys': 'uniqueKeys',
            'foreign_keys': 'foreignKeys',
            'resource_name': 'resourceName',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'types': 'types',
            'entity_properties': 'entityProperties'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._object_version = None
        self._external_key = None
        self._shape = None
        self._shape_id = None
        self._entity_type = None
        self._other_type_label = None
        self._unique_keys = None
        self._foreign_keys = None
        self._resource_name = None
        self._object_status = None
        self._identifier = None
        self._types = None
        self._entity_properties = None
        self._model_type = 'DATA_STORE_ENTITY'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateColumnSourceDetails(object):
    """
    Details to associate a column source with a masking policy.
    """

    #: A constant which can be used with the column_source property of a CreateColumnSourceDetails.
    #: This constant has a value of "TARGET"
    COLUMN_SOURCE_TARGET = "TARGET"

    #: A constant which can be used with the column_source property of a CreateColumnSourceDetails.
    #: This constant has a value of "SENSITIVE_DATA_MODEL"
    COLUMN_SOURCE_SENSITIVE_DATA_MODEL = "SENSITIVE_DATA_MODEL"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateColumnSourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_safe.models.CreateColumnSourceFromTargetDetails`
        * :class:`~oci.data_safe.models.CreateColumnSourceFromSdmDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param column_source:
            The value to assign to the column_source property of this CreateColumnSourceDetails.
            Allowed values for this property are: "TARGET", "SENSITIVE_DATA_MODEL"
        :type column_source: str

        """
        self.swagger_types = {
            'column_source': 'str'
        }

        self.attribute_map = {
            'column_source': 'columnSource'
        }

        self._column_source = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['columnSource']

        if type == 'TARGET':
            return 'CreateColumnSourceFromTargetDetails'

        if type == 'SENSITIVE_DATA_MODEL':
            return 'CreateColumnSourceFromSdmDetails'
        else:
            return 'CreateColumnSourceDetails'

    @property
    def column_source(self):
        """
        **[Required]** Gets the column_source of this CreateColumnSourceDetails.
        The source of masking columns.

        Allowed values for this property are: "TARGET", "SENSITIVE_DATA_MODEL"


        :return: The column_source of this CreateColumnSourceDetails.
        :rtype: str
        """
        return self._column_source

    @column_source.setter
    def column_source(self, column_source):
        """
        Sets the column_source of this CreateColumnSourceDetails.
        The source of masking columns.


        :param column_source: The column_source of this CreateColumnSourceDetails.
        :type: str
        """
        allowed_values = ["TARGET", "SENSITIVE_DATA_MODEL"]
        if not value_allowed_none_or_none_sentinel(column_source, allowed_values):
            raise ValueError(
                "Invalid value for `column_source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._column_source = column_source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


class FileReadCallbackStream:
    def __init__(self, file, progress_callback):
        self.progress_callback = progress_callback
        self.file = file
        self.mode = file.mode

    # this is used by 'requests' to determine the Content-Length header using fstat
    def fileno(self):
        return self.file.fileno()

    def read(self, n):
        self.progress_callback(n)
        return self.file.read(n)

    def __getattr__(self, attr):
        return getattr(self.file, attr)



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_data_guard_association_details import CreateDataGuardAssociationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataGuardAssociationToExistingVmClusterDetails(CreateDataGuardAssociationDetails):
    """
    The configuration details for creating a Data Guard association for a ExaCC Vmcluster database. For these types of vm cluster databases, the `creationType` should be `ExistingVmCluster`. A standby database will be created in the VM cluster you specify.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataGuardAssociationToExistingVmClusterDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateDataGuardAssociationToExistingVmClusterDetails.creation_type` attribute
        of this class is ``ExistingVmCluster`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type database_software_image_id: str

        :param database_admin_password:
            The value to assign to the database_admin_password property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type database_admin_password: str

        :param protection_mode:
            The value to assign to the protection_mode property of this CreateDataGuardAssociationToExistingVmClusterDetails.
            Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", "MAXIMUM_PROTECTION"
        :type protection_mode: str

        :param transport_type:
            The value to assign to the transport_type property of this CreateDataGuardAssociationToExistingVmClusterDetails.
            Allowed values for this property are: "SYNC", "ASYNC", "FASTSYNC"
        :type transport_type: str

        :param creation_type:
            The value to assign to the creation_type property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type creation_type: str

        :param is_active_data_guard_enabled:
            The value to assign to the is_active_data_guard_enabled property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type is_active_data_guard_enabled: bool

        :param peer_db_unique_name:
            The value to assign to the peer_db_unique_name property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type peer_db_unique_name: str

        :param peer_sid_prefix:
            The value to assign to the peer_sid_prefix property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type peer_sid_prefix: str

        :param peer_vm_cluster_id:
            The value to assign to the peer_vm_cluster_id property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type peer_vm_cluster_id: str

        :param peer_db_home_id:
            The value to assign to the peer_db_home_id property of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type peer_db_home_id: str

        """
        self.swagger_types = {
            'database_software_image_id': 'str',
            'database_admin_password': 'str',
            'protection_mode': 'str',
            'transport_type': 'str',
            'creation_type': 'str',
            'is_active_data_guard_enabled': 'bool',
            'peer_db_unique_name': 'str',
            'peer_sid_prefix': 'str',
            'peer_vm_cluster_id': 'str',
            'peer_db_home_id': 'str'
        }

        self.attribute_map = {
            'database_software_image_id': 'databaseSoftwareImageId',
            'database_admin_password': 'databaseAdminPassword',
            'protection_mode': 'protectionMode',
            'transport_type': 'transportType',
            'creation_type': 'creationType',
            'is_active_data_guard_enabled': 'isActiveDataGuardEnabled',
            'peer_db_unique_name': 'peerDbUniqueName',
            'peer_sid_prefix': 'peerSidPrefix',
            'peer_vm_cluster_id': 'peerVmClusterId',
            'peer_db_home_id': 'peerDbHomeId'
        }

        self._database_software_image_id = None
        self._database_admin_password = None
        self._protection_mode = None
        self._transport_type = None
        self._creation_type = None
        self._is_active_data_guard_enabled = None
        self._peer_db_unique_name = None
        self._peer_sid_prefix = None
        self._peer_vm_cluster_id = None
        self._peer_db_home_id = None
        self._creation_type = 'ExistingVmCluster'

    @property
    def peer_vm_cluster_id(self):
        """
        Gets the peer_vm_cluster_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        The `OCID`__ of the VM Cluster in which to create the standby database.
        You must supply this value if creationType is `ExistingVmCluster`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The peer_vm_cluster_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :rtype: str
        """
        return self._peer_vm_cluster_id

    @peer_vm_cluster_id.setter
    def peer_vm_cluster_id(self, peer_vm_cluster_id):
        """
        Sets the peer_vm_cluster_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        The `OCID`__ of the VM Cluster in which to create the standby database.
        You must supply this value if creationType is `ExistingVmCluster`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param peer_vm_cluster_id: The peer_vm_cluster_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type: str
        """
        self._peer_vm_cluster_id = peer_vm_cluster_id

    @property
    def peer_db_home_id(self):
        """
        Gets the peer_db_home_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        The `OCID`__ of the DB home in which to create the standby database.
        You must supply this value to create standby database with an existing DB home

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The peer_db_home_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :rtype: str
        """
        return self._peer_db_home_id

    @peer_db_home_id.setter
    def peer_db_home_id(self, peer_db_home_id):
        """
        Sets the peer_db_home_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        The `OCID`__ of the DB home in which to create the standby database.
        You must supply this value to create standby database with an existing DB home

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param peer_db_home_id: The peer_db_home_id of this CreateDataGuardAssociationToExistingVmClusterDetails.
        :type: str
        """
        self._peer_db_home_id = peer_db_home_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NamespaceMetric(object):
    """
    Metric associated with a namespace.
    """

    #: A constant which can be used with the type property of a NamespaceMetric.
    #: This constant has a value of "COUNTER"
    TYPE_COUNTER = "COUNTER"

    #: A constant which can be used with the type property of a NamespaceMetric.
    #: This constant has a value of "GAUGE"
    TYPE_GAUGE = "GAUGE"

    def __init__(self, **kwargs):
        """
        Initializes a new NamespaceMetric object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this NamespaceMetric.
        :type name: str

        :param type:
            The value to assign to the type property of this NamespaceMetric.
            Allowed values for this property are: "COUNTER", "GAUGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param unit:
            The value to assign to the unit property of this NamespaceMetric.
        :type unit: str

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'unit': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'unit': 'unit'
        }

        self._name = None
        self._type = None
        self._unit = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this NamespaceMetric.
        Name of the metric.


        :return: The name of this NamespaceMetric.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NamespaceMetric.
        Name of the metric.


        :param name: The name of this NamespaceMetric.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this NamespaceMetric.
        Type of metric.

        Allowed values for this property are: "COUNTER", "GAUGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this NamespaceMetric.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this NamespaceMetric.
        Type of metric.


        :param type: The type of this NamespaceMetric.
        :type: str
        """
        allowed_values = ["COUNTER", "GAUGE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def unit(self):
        """
        Gets the unit of this NamespaceMetric.
        Unit of the metric.


        :return: The unit of this NamespaceMetric.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this NamespaceMetric.
        Unit of the metric.


        :param unit: The unit of this NamespaceMetric.
        :type: str
        """
        self._unit = unit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .patch_instruction import PatchInstruction
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchInsertInstruction(PatchInstruction):
    """
    An operation that inserts a value into an array, shifting array items as necessary and handling NOT_FOUND exceptions by creating the implied containing structure.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PatchInsertInstruction object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.PatchInsertInstruction.operation` attribute
        of this class is ``INSERT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this PatchInsertInstruction.
            Allowed values for this property are: "INSERT", "REMOVE", "MERGE"
        :type operation: str

        :param selection:
            The value to assign to the selection property of this PatchInsertInstruction.
        :type selection: str

        :param value:
            The value to assign to the value property of this PatchInsertInstruction.
        :type value: object

        """
        self.swagger_types = {
            'operation': 'str',
            'selection': 'str',
            'value': 'object'
        }

        self.attribute_map = {
            'operation': 'operation',
            'selection': 'selection',
            'value': 'value'
        }

        self._operation = None
        self._selection = None
        self._value = None
        self._operation = 'INSERT'

    @property
    def value(self):
        """
        **[Required]** Gets the value of this PatchInsertInstruction.
        A value to be inserted into the target.


        :return: The value of this PatchInsertInstruction.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this PatchInsertInstruction.
        A value to be inserted into the target.


        :param value: The value of this PatchInsertInstruction.
        :type: object
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseCharacterSets(object):
    """
    The Oracle Autonomous Database supported character sets.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseCharacterSets object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AutonomousDatabaseCharacterSets.
        :type name: str

        """
        self.swagger_types = {
            'name': 'str'
        }

        self.attribute_map = {
            'name': 'name'
        }

        self._name = None

    @property
    def name(self):
        """
        Gets the name of this AutonomousDatabaseCharacterSets.
        A valid Oracle character set.


        :return: The name of this AutonomousDatabaseCharacterSets.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AutonomousDatabaseCharacterSets.
        A valid Oracle character set.


        :param name: The name of this AutonomousDatabaseCharacterSets.
        :type: str
        """
        self._name = name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .drg_route_distribution_match_criteria import DrgRouteDistributionMatchCriteria
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgAttachmentIdDrgRouteDistributionMatchCriteria(DrgRouteDistributionMatchCriteria):
    """
    The criteria by which a specific attachment will import routes to the DRG.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DrgAttachmentIdDrgRouteDistributionMatchCriteria object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.DrgAttachmentIdDrgRouteDistributionMatchCriteria.match_type` attribute
        of this class is ``DRG_ATTACHMENT_ID`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param match_type:
            The value to assign to the match_type property of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
            Allowed values for this property are: "DRG_ATTACHMENT_TYPE", "DRG_ATTACHMENT_ID"
        :type match_type: str

        :param drg_attachment_id:
            The value to assign to the drg_attachment_id property of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
        :type drg_attachment_id: str

        """
        self.swagger_types = {
            'match_type': 'str',
            'drg_attachment_id': 'str'
        }

        self.attribute_map = {
            'match_type': 'matchType',
            'drg_attachment_id': 'drgAttachmentId'
        }

        self._match_type = None
        self._drg_attachment_id = None
        self._match_type = 'DRG_ATTACHMENT_ID'

    @property
    def drg_attachment_id(self):
        """
        **[Required]** Gets the drg_attachment_id of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
        The `OCID`__ of the DRG attachment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The drg_attachment_id of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
        :rtype: str
        """
        return self._drg_attachment_id

    @drg_attachment_id.setter
    def drg_attachment_id(self, drg_attachment_id):
        """
        Sets the drg_attachment_id of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
        The `OCID`__ of the DRG attachment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param drg_attachment_id: The drg_attachment_id of this DrgAttachmentIdDrgRouteDistributionMatchCriteria.
        :type: str
        """
        self._drg_attachment_id = drg_attachment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTablespaceDetails(object):
    """
    The details required to create a tablespace.
    """

    #: A constant which can be used with the type property of a CreateTablespaceDetails.
    #: This constant has a value of "PERMANENT"
    TYPE_PERMANENT = "PERMANENT"

    #: A constant which can be used with the type property of a CreateTablespaceDetails.
    #: This constant has a value of "TEMPORARY"
    TYPE_TEMPORARY = "TEMPORARY"

    #: A constant which can be used with the default_compress property of a CreateTablespaceDetails.
    #: This constant has a value of "NO_COMPRESS"
    DEFAULT_COMPRESS_NO_COMPRESS = "NO_COMPRESS"

    #: A constant which can be used with the default_compress property of a CreateTablespaceDetails.
    #: This constant has a value of "BASIC_COMPRESS"
    DEFAULT_COMPRESS_BASIC_COMPRESS = "BASIC_COMPRESS"

    #: A constant which can be used with the status property of a CreateTablespaceDetails.
    #: This constant has a value of "READ_ONLY"
    STATUS_READ_ONLY = "READ_ONLY"

    #: A constant which can be used with the status property of a CreateTablespaceDetails.
    #: This constant has a value of "READ_WRITE"
    STATUS_READ_WRITE = "READ_WRITE"

    #: A constant which can be used with the extent_management property of a CreateTablespaceDetails.
    #: This constant has a value of "AUTOALLOCATE"
    EXTENT_MANAGEMENT_AUTOALLOCATE = "AUTOALLOCATE"

    #: A constant which can be used with the extent_management property of a CreateTablespaceDetails.
    #: This constant has a value of "UNIFORM"
    EXTENT_MANAGEMENT_UNIFORM = "UNIFORM"

    #: A constant which can be used with the segment_management property of a CreateTablespaceDetails.
    #: This constant has a value of "AUTO"
    SEGMENT_MANAGEMENT_AUTO = "AUTO"

    #: A constant which can be used with the segment_management property of a CreateTablespaceDetails.
    #: This constant has a value of "MANUAL"
    SEGMENT_MANAGEMENT_MANUAL = "MANUAL"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTablespaceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credential_details:
            The value to assign to the credential_details property of this CreateTablespaceDetails.
        :type credential_details: oci.database_management.models.TablespaceAdminCredentialDetails

        :param name:
            The value to assign to the name property of this CreateTablespaceDetails.
        :type name: str

        :param type:
            The value to assign to the type property of this CreateTablespaceDetails.
            Allowed values for this property are: "PERMANENT", "TEMPORARY"
        :type type: str

        :param is_bigfile:
            The value to assign to the is_bigfile property of this CreateTablespaceDetails.
        :type is_bigfile: bool

        :param data_files:
            The value to assign to the data_files property of this CreateTablespaceDetails.
        :type data_files: list[str]

        :param file_count:
            The value to assign to the file_count property of this CreateTablespaceDetails.
        :type file_count: int

        :param file_size:
            The value to assign to the file_size property of this CreateTablespaceDetails.
        :type file_size: oci.database_management.models.TablespaceStorageSize

        :param is_reusable:
            The value to assign to the is_reusable property of this CreateTablespaceDetails.
        :type is_reusable: bool

        :param is_auto_extensible:
            The value to assign to the is_auto_extensible property of this CreateTablespaceDetails.
        :type is_auto_extensible: bool

        :param auto_extend_next_size:
            The value to assign to the auto_extend_next_size property of this CreateTablespaceDetails.
        :type auto_extend_next_size: oci.database_management.models.TablespaceStorageSize

        :param auto_extend_max_size:
            The value to assign to the auto_extend_max_size property of this CreateTablespaceDetails.
        :type auto_extend_max_size: oci.database_management.models.TablespaceStorageSize

        :param is_max_size_unlimited:
            The value to assign to the is_max_size_unlimited property of this CreateTablespaceDetails.
        :type is_max_size_unlimited: bool

        :param block_size_in_kilobytes:
            The value to assign to the block_size_in_kilobytes property of this CreateTablespaceDetails.
        :type block_size_in_kilobytes: int

        :param is_encrypted:
            The value to assign to the is_encrypted property of this CreateTablespaceDetails.
        :type is_encrypted: bool

        :param encryption_algorithm:
            The value to assign to the encryption_algorithm property of this CreateTablespaceDetails.
        :type encryption_algorithm: str

        :param default_compress:
            The value to assign to the default_compress property of this CreateTablespaceDetails.
            Allowed values for this property are: "NO_COMPRESS", "BASIC_COMPRESS"
        :type default_compress: str

        :param status:
            The value to assign to the status property of this CreateTablespaceDetails.
            Allowed values for this property are: "READ_ONLY", "READ_WRITE"
        :type status: str

        :param extent_management:
            The value to assign to the extent_management property of this CreateTablespaceDetails.
            Allowed values for this property are: "AUTOALLOCATE", "UNIFORM"
        :type extent_management: str

        :param extent_uniform_size:
            The value to assign to the extent_uniform_size property of this CreateTablespaceDetails.
        :type extent_uniform_size: oci.database_management.models.TablespaceStorageSize

        :param segment_management:
            The value to assign to the segment_management property of this CreateTablespaceDetails.
            Allowed values for this property are: "AUTO", "MANUAL"
        :type segment_management: str

        :param is_default:
            The value to assign to the is_default property of this CreateTablespaceDetails.
        :type is_default: bool

        """
        self.swagger_types = {
            'credential_details': 'TablespaceAdminCredentialDetails',
            'name': 'str',
            'type': 'str',
            'is_bigfile': 'bool',
            'data_files': 'list[str]',
            'file_count': 'int',
            'file_size': 'TablespaceStorageSize',
            'is_reusable': 'bool',
            'is_auto_extensible': 'bool',
            'auto_extend_next_size': 'TablespaceStorageSize',
            'auto_extend_max_size': 'TablespaceStorageSize',
            'is_max_size_unlimited': 'bool',
            'block_size_in_kilobytes': 'int',
            'is_encrypted': 'bool',
            'encryption_algorithm': 'str',
            'default_compress': 'str',
            'status': 'str',
            'extent_management': 'str',
            'extent_uniform_size': 'TablespaceStorageSize',
            'segment_management': 'str',
            'is_default': 'bool'
        }

        self.attribute_map = {
            'credential_details': 'credentialDetails',
            'name': 'name',
            'type': 'type',
            'is_bigfile': 'isBigfile',
            'data_files': 'dataFiles',
            'file_count': 'fileCount',
            'file_size': 'fileSize',
            'is_reusable': 'isReusable',
            'is_auto_extensible': 'isAutoExtensible',
            'auto_extend_next_size': 'autoExtendNextSize',
            'auto_extend_max_size': 'autoExtendMaxSize',
            'is_max_size_unlimited': 'isMaxSizeUnlimited',
            'block_size_in_kilobytes': 'blockSizeInKilobytes',
            'is_encrypted': 'isEncrypted',
            'encryption_algorithm': 'encryptionAlgorithm',
            'default_compress': 'defaultCompress',
            'status': 'status',
            'extent_management': 'extentManagement',
            'extent_uniform_size': 'extentUniformSize',
            'segment_management': 'segmentManagement',
            'is_default': 'isDefault'
        }

        self._credential_details = None
        self._name = None
        self._type = None
        self._is_bigfile = None
        self._data_files = None
        self._file_count = None
        self._file_size = None
        self._is_reusable = None
        self._is_auto_extensible = None
        self._auto_extend_next_size = None
        self._auto_extend_max_size = None
        self._is_max_size_unlimited = None
        self._block_size_in_kilobytes = None
        self._is_encrypted = None
        self._encryption_algorithm = None
        self._default_compress = None
        self._status = None
        self._extent_management = None
        self._extent_uniform_size = None
        self._segment_management = None
        self._is_default = None

    @property
    def credential_details(self):
        """
        **[Required]** Gets the credential_details of this CreateTablespaceDetails.

        :return: The credential_details of this CreateTablespaceDetails.
        :rtype: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        return self._credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        """
        Sets the credential_details of this CreateTablespaceDetails.

        :param credential_details: The credential_details of this CreateTablespaceDetails.
        :type: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        self._credential_details = credential_details

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateTablespaceDetails.
        The name of the tablespace. It must be unique within a database.


        :return: The name of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateTablespaceDetails.
        The name of the tablespace. It must be unique within a database.


        :param name: The name of this CreateTablespaceDetails.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this CreateTablespaceDetails.
        The type of tablespace.

        Allowed values for this property are: "PERMANENT", "TEMPORARY"


        :return: The type of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreateTablespaceDetails.
        The type of tablespace.


        :param type: The type of this CreateTablespaceDetails.
        :type: str
        """
        allowed_values = ["PERMANENT", "TEMPORARY"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def is_bigfile(self):
        """
        Gets the is_bigfile of this CreateTablespaceDetails.
        Specifies whether the tablespace is a bigfile or smallfile tablespace.
        A bigfile tablespace contains only one data file or temp file, which can contain up to approximately 4 billion (232) blocks.
        A smallfile tablespace is a traditional Oracle tablespace, which can contain 1022 data files or temp files, each of which can contain up to approximately 4 million (222) blocks.


        :return: The is_bigfile of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_bigfile

    @is_bigfile.setter
    def is_bigfile(self, is_bigfile):
        """
        Sets the is_bigfile of this CreateTablespaceDetails.
        Specifies whether the tablespace is a bigfile or smallfile tablespace.
        A bigfile tablespace contains only one data file or temp file, which can contain up to approximately 4 billion (232) blocks.
        A smallfile tablespace is a traditional Oracle tablespace, which can contain 1022 data files or temp files, each of which can contain up to approximately 4 million (222) blocks.


        :param is_bigfile: The is_bigfile of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_bigfile = is_bigfile

    @property
    def data_files(self):
        """
        Gets the data_files of this CreateTablespaceDetails.
        The list of data files or temp files created for the tablespace.


        :return: The data_files of this CreateTablespaceDetails.
        :rtype: list[str]
        """
        return self._data_files

    @data_files.setter
    def data_files(self, data_files):
        """
        Sets the data_files of this CreateTablespaceDetails.
        The list of data files or temp files created for the tablespace.


        :param data_files: The data_files of this CreateTablespaceDetails.
        :type: list[str]
        """
        self._data_files = data_files

    @property
    def file_count(self):
        """
        Gets the file_count of this CreateTablespaceDetails.
        The number of data files or temp files created for the tablespace. This is for Oracle Managed Files only.


        :return: The file_count of this CreateTablespaceDetails.
        :rtype: int
        """
        return self._file_count

    @file_count.setter
    def file_count(self, file_count):
        """
        Sets the file_count of this CreateTablespaceDetails.
        The number of data files or temp files created for the tablespace. This is for Oracle Managed Files only.


        :param file_count: The file_count of this CreateTablespaceDetails.
        :type: int
        """
        self._file_count = file_count

    @property
    def file_size(self):
        """
        Gets the file_size of this CreateTablespaceDetails.
        The size of each data file or temp file.


        :return: The file_size of this CreateTablespaceDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """
        Sets the file_size of this CreateTablespaceDetails.
        The size of each data file or temp file.


        :param file_size: The file_size of this CreateTablespaceDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._file_size = file_size

    @property
    def is_reusable(self):
        """
        Gets the is_reusable of this CreateTablespaceDetails.
        Specifies whether Oracle can reuse the data file or temp file. Reuse is only allowed when the file name is provided.


        :return: The is_reusable of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_reusable

    @is_reusable.setter
    def is_reusable(self, is_reusable):
        """
        Sets the is_reusable of this CreateTablespaceDetails.
        Specifies whether Oracle can reuse the data file or temp file. Reuse is only allowed when the file name is provided.


        :param is_reusable: The is_reusable of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_reusable = is_reusable

    @property
    def is_auto_extensible(self):
        """
        Gets the is_auto_extensible of this CreateTablespaceDetails.
        Specifies whether the data file or temp file can be extended automatically.


        :return: The is_auto_extensible of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_auto_extensible

    @is_auto_extensible.setter
    def is_auto_extensible(self, is_auto_extensible):
        """
        Sets the is_auto_extensible of this CreateTablespaceDetails.
        Specifies whether the data file or temp file can be extended automatically.


        :param is_auto_extensible: The is_auto_extensible of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_auto_extensible = is_auto_extensible

    @property
    def auto_extend_next_size(self):
        """
        Gets the auto_extend_next_size of this CreateTablespaceDetails.
        The size of the next increment of disk space to be allocated automatically when more extents are required.


        :return: The auto_extend_next_size of this CreateTablespaceDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._auto_extend_next_size

    @auto_extend_next_size.setter
    def auto_extend_next_size(self, auto_extend_next_size):
        """
        Sets the auto_extend_next_size of this CreateTablespaceDetails.
        The size of the next increment of disk space to be allocated automatically when more extents are required.


        :param auto_extend_next_size: The auto_extend_next_size of this CreateTablespaceDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._auto_extend_next_size = auto_extend_next_size

    @property
    def auto_extend_max_size(self):
        """
        Gets the auto_extend_max_size of this CreateTablespaceDetails.
        The maximum disk space allowed for automatic extension of the data files or temp files.


        :return: The auto_extend_max_size of this CreateTablespaceDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._auto_extend_max_size

    @auto_extend_max_size.setter
    def auto_extend_max_size(self, auto_extend_max_size):
        """
        Sets the auto_extend_max_size of this CreateTablespaceDetails.
        The maximum disk space allowed for automatic extension of the data files or temp files.


        :param auto_extend_max_size: The auto_extend_max_size of this CreateTablespaceDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._auto_extend_max_size = auto_extend_max_size

    @property
    def is_max_size_unlimited(self):
        """
        Gets the is_max_size_unlimited of this CreateTablespaceDetails.
        Specifies whether the disk space of the data file or temp file can be limited.


        :return: The is_max_size_unlimited of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_max_size_unlimited

    @is_max_size_unlimited.setter
    def is_max_size_unlimited(self, is_max_size_unlimited):
        """
        Sets the is_max_size_unlimited of this CreateTablespaceDetails.
        Specifies whether the disk space of the data file or temp file can be limited.


        :param is_max_size_unlimited: The is_max_size_unlimited of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_max_size_unlimited = is_max_size_unlimited

    @property
    def block_size_in_kilobytes(self):
        """
        Gets the block_size_in_kilobytes of this CreateTablespaceDetails.
        Block size for the tablespace.


        :return: The block_size_in_kilobytes of this CreateTablespaceDetails.
        :rtype: int
        """
        return self._block_size_in_kilobytes

    @block_size_in_kilobytes.setter
    def block_size_in_kilobytes(self, block_size_in_kilobytes):
        """
        Sets the block_size_in_kilobytes of this CreateTablespaceDetails.
        Block size for the tablespace.


        :param block_size_in_kilobytes: The block_size_in_kilobytes of this CreateTablespaceDetails.
        :type: int
        """
        self._block_size_in_kilobytes = block_size_in_kilobytes

    @property
    def is_encrypted(self):
        """
        Gets the is_encrypted of this CreateTablespaceDetails.
        Indicates whether the tablespace is encrypted.


        :return: The is_encrypted of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """
        Sets the is_encrypted of this CreateTablespaceDetails.
        Indicates whether the tablespace is encrypted.


        :param is_encrypted: The is_encrypted of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_encrypted = is_encrypted

    @property
    def encryption_algorithm(self):
        """
        Gets the encryption_algorithm of this CreateTablespaceDetails.
        The name of the encryption algorithm to be used for tablespace encryption.


        :return: The encryption_algorithm of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._encryption_algorithm

    @encryption_algorithm.setter
    def encryption_algorithm(self, encryption_algorithm):
        """
        Sets the encryption_algorithm of this CreateTablespaceDetails.
        The name of the encryption algorithm to be used for tablespace encryption.


        :param encryption_algorithm: The encryption_algorithm of this CreateTablespaceDetails.
        :type: str
        """
        self._encryption_algorithm = encryption_algorithm

    @property
    def default_compress(self):
        """
        Gets the default_compress of this CreateTablespaceDetails.
        The default compression of data for all tables created in the tablespace.

        Allowed values for this property are: "NO_COMPRESS", "BASIC_COMPRESS"


        :return: The default_compress of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._default_compress

    @default_compress.setter
    def default_compress(self, default_compress):
        """
        Sets the default_compress of this CreateTablespaceDetails.
        The default compression of data for all tables created in the tablespace.


        :param default_compress: The default_compress of this CreateTablespaceDetails.
        :type: str
        """
        allowed_values = ["NO_COMPRESS", "BASIC_COMPRESS"]
        if not value_allowed_none_or_none_sentinel(default_compress, allowed_values):
            raise ValueError(
                "Invalid value for `default_compress`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._default_compress = default_compress

    @property
    def status(self):
        """
        Gets the status of this CreateTablespaceDetails.
        The status of the tablespace.

        Allowed values for this property are: "READ_ONLY", "READ_WRITE"


        :return: The status of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this CreateTablespaceDetails.
        The status of the tablespace.


        :param status: The status of this CreateTablespaceDetails.
        :type: str
        """
        allowed_values = ["READ_ONLY", "READ_WRITE"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            raise ValueError(
                "Invalid value for `status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def extent_management(self):
        """
        Gets the extent_management of this CreateTablespaceDetails.
        Specifies how the extents of the tablespace should be managed.

        Allowed values for this property are: "AUTOALLOCATE", "UNIFORM"


        :return: The extent_management of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._extent_management

    @extent_management.setter
    def extent_management(self, extent_management):
        """
        Sets the extent_management of this CreateTablespaceDetails.
        Specifies how the extents of the tablespace should be managed.


        :param extent_management: The extent_management of this CreateTablespaceDetails.
        :type: str
        """
        allowed_values = ["AUTOALLOCATE", "UNIFORM"]
        if not value_allowed_none_or_none_sentinel(extent_management, allowed_values):
            raise ValueError(
                "Invalid value for `extent_management`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._extent_management = extent_management

    @property
    def extent_uniform_size(self):
        """
        Gets the extent_uniform_size of this CreateTablespaceDetails.
        The size of the extent when the tablespace is managed with uniform extents of a specific size.


        :return: The extent_uniform_size of this CreateTablespaceDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._extent_uniform_size

    @extent_uniform_size.setter
    def extent_uniform_size(self, extent_uniform_size):
        """
        Sets the extent_uniform_size of this CreateTablespaceDetails.
        The size of the extent when the tablespace is managed with uniform extents of a specific size.


        :param extent_uniform_size: The extent_uniform_size of this CreateTablespaceDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._extent_uniform_size = extent_uniform_size

    @property
    def segment_management(self):
        """
        Gets the segment_management of this CreateTablespaceDetails.
        Specifies whether tablespace segment management should be automatic or manual.

        Allowed values for this property are: "AUTO", "MANUAL"


        :return: The segment_management of this CreateTablespaceDetails.
        :rtype: str
        """
        return self._segment_management

    @segment_management.setter
    def segment_management(self, segment_management):
        """
        Sets the segment_management of this CreateTablespaceDetails.
        Specifies whether tablespace segment management should be automatic or manual.


        :param segment_management: The segment_management of this CreateTablespaceDetails.
        :type: str
        """
        allowed_values = ["AUTO", "MANUAL"]
        if not value_allowed_none_or_none_sentinel(segment_management, allowed_values):
            raise ValueError(
                "Invalid value for `segment_management`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._segment_management = segment_management

    @property
    def is_default(self):
        """
        Gets the is_default of this CreateTablespaceDetails.
        Specifies whether the tablespace is the default tablespace.


        :return: The is_default of this CreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this CreateTablespaceDetails.
        Specifies whether the tablespace is the default tablespace.


        :param is_default: The is_default of this CreateTablespaceDetails.
        :type: bool
        """
        self._is_default = is_default

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TopUtilizedResourceSummary(object):
    """
    A summary of a top utlized resource.
    """

    #: A constant which can be used with the unit_type property of a TopUtilizedResourceSummary.
    #: This constant has a value of "OCPU"
    UNIT_TYPE_OCPU = "OCPU"

    def __init__(self, **kwargs):
        """
        Initializes a new TopUtilizedResourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_id:
            The value to assign to the resource_id property of this TopUtilizedResourceSummary.
        :type resource_id: str

        :param resource_name:
            The value to assign to the resource_name property of this TopUtilizedResourceSummary.
        :type resource_name: str

        :param resource_compartment_id:
            The value to assign to the resource_compartment_id property of this TopUtilizedResourceSummary.
        :type resource_compartment_id: str

        :param resource_compartment_name:
            The value to assign to the resource_compartment_name property of this TopUtilizedResourceSummary.
        :type resource_compartment_name: str

        :param total_units:
            The value to assign to the total_units property of this TopUtilizedResourceSummary.
        :type total_units: float

        :param unit_type:
            The value to assign to the unit_type property of this TopUtilizedResourceSummary.
            Allowed values for this property are: "OCPU", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit_type: str

        """
        self.swagger_types = {
            'resource_id': 'str',
            'resource_name': 'str',
            'resource_compartment_id': 'str',
            'resource_compartment_name': 'str',
            'total_units': 'float',
            'unit_type': 'str'
        }

        self.attribute_map = {
            'resource_id': 'resourceId',
            'resource_name': 'resourceName',
            'resource_compartment_id': 'resourceCompartmentId',
            'resource_compartment_name': 'resourceCompartmentName',
            'total_units': 'totalUnits',
            'unit_type': 'unitType'
        }

        self._resource_id = None
        self._resource_name = None
        self._resource_compartment_id = None
        self._resource_compartment_name = None
        self._total_units = None
        self._unit_type = None

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this TopUtilizedResourceSummary.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_id of this TopUtilizedResourceSummary.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this TopUtilizedResourceSummary.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_id: The resource_id of this TopUtilizedResourceSummary.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this TopUtilizedResourceSummary.
        Resource canonical name.


        :return: The resource_name of this TopUtilizedResourceSummary.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this TopUtilizedResourceSummary.
        Resource canonical name.


        :param resource_name: The resource_name of this TopUtilizedResourceSummary.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def resource_compartment_id(self):
        """
        **[Required]** Gets the resource_compartment_id of this TopUtilizedResourceSummary.
        The compartment `OCID`__ that contains the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_compartment_id of this TopUtilizedResourceSummary.
        :rtype: str
        """
        return self._resource_compartment_id

    @resource_compartment_id.setter
    def resource_compartment_id(self, resource_compartment_id):
        """
        Sets the resource_compartment_id of this TopUtilizedResourceSummary.
        The compartment `OCID`__ that contains the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_compartment_id: The resource_compartment_id of this TopUtilizedResourceSummary.
        :type: str
        """
        self._resource_compartment_id = resource_compartment_id

    @property
    def resource_compartment_name(self):
        """
        **[Required]** Gets the resource_compartment_name of this TopUtilizedResourceSummary.
        The display name of the compartment that contains the resource.


        :return: The resource_compartment_name of this TopUtilizedResourceSummary.
        :rtype: str
        """
        return self._resource_compartment_name

    @resource_compartment_name.setter
    def resource_compartment_name(self, resource_compartment_name):
        """
        Sets the resource_compartment_name of this TopUtilizedResourceSummary.
        The display name of the compartment that contains the resource.


        :param resource_compartment_name: The resource_compartment_name of this TopUtilizedResourceSummary.
        :type: str
        """
        self._resource_compartment_name = resource_compartment_name

    @property
    def total_units(self):
        """
        **[Required]** Gets the total_units of this TopUtilizedResourceSummary.
        Number of license units consumed by the resource.


        :return: The total_units of this TopUtilizedResourceSummary.
        :rtype: float
        """
        return self._total_units

    @total_units.setter
    def total_units(self, total_units):
        """
        Sets the total_units of this TopUtilizedResourceSummary.
        Number of license units consumed by the resource.


        :param total_units: The total_units of this TopUtilizedResourceSummary.
        :type: float
        """
        self._total_units = total_units

    @property
    def unit_type(self):
        """
        **[Required]** Gets the unit_type of this TopUtilizedResourceSummary.
        The resource unit.

        Allowed values for this property are: "OCPU", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit_type of this TopUtilizedResourceSummary.
        :rtype: str
        """
        return self._unit_type

    @unit_type.setter
    def unit_type(self, unit_type):
        """
        Sets the unit_type of this TopUtilizedResourceSummary.
        The resource unit.


        :param unit_type: The unit_type of this TopUtilizedResourceSummary.
        :type: str
        """
        allowed_values = ["OCPU"]
        if not value_allowed_none_or_none_sentinel(unit_type, allowed_values):
            unit_type = 'UNKNOWN_ENUM_VALUE'
        self._unit_type = unit_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SummarizeExadataInsightResourceUsageCollection(object):
    """
    Resource usage , allocation, utilization and usage ChangePercent for the current time period
    """

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "CPU"
    EXADATA_RESOURCE_METRIC_CPU = "CPU"

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "STORAGE"
    EXADATA_RESOURCE_METRIC_STORAGE = "STORAGE"

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "IO"
    EXADATA_RESOURCE_METRIC_IO = "IO"

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "MEMORY"
    EXADATA_RESOURCE_METRIC_MEMORY = "MEMORY"

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "IOPS"
    EXADATA_RESOURCE_METRIC_IOPS = "IOPS"

    #: A constant which can be used with the exadata_resource_metric property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "THROUGHPUT"
    EXADATA_RESOURCE_METRIC_THROUGHPUT = "THROUGHPUT"

    #: A constant which can be used with the exadata_resource_type property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "DATABASE"
    EXADATA_RESOURCE_TYPE_DATABASE = "DATABASE"

    #: A constant which can be used with the exadata_resource_type property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "HOST"
    EXADATA_RESOURCE_TYPE_HOST = "HOST"

    #: A constant which can be used with the exadata_resource_type property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "STORAGE_SERVER"
    EXADATA_RESOURCE_TYPE_STORAGE_SERVER = "STORAGE_SERVER"

    #: A constant which can be used with the exadata_resource_type property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "DISKGROUP"
    EXADATA_RESOURCE_TYPE_DISKGROUP = "DISKGROUP"

    #: A constant which can be used with the usage_unit property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "CORES"
    USAGE_UNIT_CORES = "CORES"

    #: A constant which can be used with the usage_unit property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "GB"
    USAGE_UNIT_GB = "GB"

    #: A constant which can be used with the usage_unit property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "MBPS"
    USAGE_UNIT_MBPS = "MBPS"

    #: A constant which can be used with the usage_unit property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "IOPS"
    USAGE_UNIT_IOPS = "IOPS"

    #: A constant which can be used with the usage_unit property of a SummarizeExadataInsightResourceUsageCollection.
    #: This constant has a value of "PERCENT"
    USAGE_UNIT_PERCENT = "PERCENT"

    def __init__(self, **kwargs):
        """
        Initializes a new SummarizeExadataInsightResourceUsageCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_interval_start:
            The value to assign to the time_interval_start property of this SummarizeExadataInsightResourceUsageCollection.
        :type time_interval_start: datetime

        :param time_interval_end:
            The value to assign to the time_interval_end property of this SummarizeExadataInsightResourceUsageCollection.
        :type time_interval_end: datetime

        :param exadata_resource_metric:
            The value to assign to the exadata_resource_metric property of this SummarizeExadataInsightResourceUsageCollection.
            Allowed values for this property are: "CPU", "STORAGE", "IO", "MEMORY", "IOPS", "THROUGHPUT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_resource_metric: str

        :param exadata_resource_type:
            The value to assign to the exadata_resource_type property of this SummarizeExadataInsightResourceUsageCollection.
            Allowed values for this property are: "DATABASE", "HOST", "STORAGE_SERVER", "DISKGROUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_resource_type: str

        :param usage_unit:
            The value to assign to the usage_unit property of this SummarizeExadataInsightResourceUsageCollection.
            Allowed values for this property are: "CORES", "GB", "MBPS", "IOPS", "PERCENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type usage_unit: str

        :param items:
            The value to assign to the items property of this SummarizeExadataInsightResourceUsageCollection.
        :type items: list[oci.opsi.models.ResourceUsageSummary]

        """
        self.swagger_types = {
            'time_interval_start': 'datetime',
            'time_interval_end': 'datetime',
            'exadata_resource_metric': 'str',
            'exadata_resource_type': 'str',
            'usage_unit': 'str',
            'items': 'list[ResourceUsageSummary]'
        }

        self.attribute_map = {
            'time_interval_start': 'timeIntervalStart',
            'time_interval_end': 'timeIntervalEnd',
            'exadata_resource_metric': 'exadataResourceMetric',
            'exadata_resource_type': 'exadataResourceType',
            'usage_unit': 'usageUnit',
            'items': 'items'
        }

        self._time_interval_start = None
        self._time_interval_end = None
        self._exadata_resource_metric = None
        self._exadata_resource_type = None
        self._usage_unit = None
        self._items = None

    @property
    def time_interval_start(self):
        """
        **[Required]** Gets the time_interval_start of this SummarizeExadataInsightResourceUsageCollection.
        The start timestamp that was passed into the request.


        :return: The time_interval_start of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: datetime
        """
        return self._time_interval_start

    @time_interval_start.setter
    def time_interval_start(self, time_interval_start):
        """
        Sets the time_interval_start of this SummarizeExadataInsightResourceUsageCollection.
        The start timestamp that was passed into the request.


        :param time_interval_start: The time_interval_start of this SummarizeExadataInsightResourceUsageCollection.
        :type: datetime
        """
        self._time_interval_start = time_interval_start

    @property
    def time_interval_end(self):
        """
        **[Required]** Gets the time_interval_end of this SummarizeExadataInsightResourceUsageCollection.
        The end timestamp that was passed into the request.


        :return: The time_interval_end of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: datetime
        """
        return self._time_interval_end

    @time_interval_end.setter
    def time_interval_end(self, time_interval_end):
        """
        Sets the time_interval_end of this SummarizeExadataInsightResourceUsageCollection.
        The end timestamp that was passed into the request.


        :param time_interval_end: The time_interval_end of this SummarizeExadataInsightResourceUsageCollection.
        :type: datetime
        """
        self._time_interval_end = time_interval_end

    @property
    def exadata_resource_metric(self):
        """
        **[Required]** Gets the exadata_resource_metric of this SummarizeExadataInsightResourceUsageCollection.
        Defines the type of exadata resource metric (example: CPU, STORAGE)

        Allowed values for this property are: "CPU", "STORAGE", "IO", "MEMORY", "IOPS", "THROUGHPUT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_resource_metric of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: str
        """
        return self._exadata_resource_metric

    @exadata_resource_metric.setter
    def exadata_resource_metric(self, exadata_resource_metric):
        """
        Sets the exadata_resource_metric of this SummarizeExadataInsightResourceUsageCollection.
        Defines the type of exadata resource metric (example: CPU, STORAGE)


        :param exadata_resource_metric: The exadata_resource_metric of this SummarizeExadataInsightResourceUsageCollection.
        :type: str
        """
        allowed_values = ["CPU", "STORAGE", "IO", "MEMORY", "IOPS", "THROUGHPUT"]
        if not value_allowed_none_or_none_sentinel(exadata_resource_metric, allowed_values):
            exadata_resource_metric = 'UNKNOWN_ENUM_VALUE'
        self._exadata_resource_metric = exadata_resource_metric

    @property
    def exadata_resource_type(self):
        """
        **[Required]** Gets the exadata_resource_type of this SummarizeExadataInsightResourceUsageCollection.
        Defines the resource type for an exadata  (example: DATABASE, STORAGE_SERVER, HOST, DISKGROUP)

        Allowed values for this property are: "DATABASE", "HOST", "STORAGE_SERVER", "DISKGROUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_resource_type of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: str
        """
        return self._exadata_resource_type

    @exadata_resource_type.setter
    def exadata_resource_type(self, exadata_resource_type):
        """
        Sets the exadata_resource_type of this SummarizeExadataInsightResourceUsageCollection.
        Defines the resource type for an exadata  (example: DATABASE, STORAGE_SERVER, HOST, DISKGROUP)


        :param exadata_resource_type: The exadata_resource_type of this SummarizeExadataInsightResourceUsageCollection.
        :type: str
        """
        allowed_values = ["DATABASE", "HOST", "STORAGE_SERVER", "DISKGROUP"]
        if not value_allowed_none_or_none_sentinel(exadata_resource_type, allowed_values):
            exadata_resource_type = 'UNKNOWN_ENUM_VALUE'
        self._exadata_resource_type = exadata_resource_type

    @property
    def usage_unit(self):
        """
        **[Required]** Gets the usage_unit of this SummarizeExadataInsightResourceUsageCollection.
        Displays usage unit (CORES, GB)

        Allowed values for this property are: "CORES", "GB", "MBPS", "IOPS", "PERCENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The usage_unit of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: str
        """
        return self._usage_unit

    @usage_unit.setter
    def usage_unit(self, usage_unit):
        """
        Sets the usage_unit of this SummarizeExadataInsightResourceUsageCollection.
        Displays usage unit (CORES, GB)


        :param usage_unit: The usage_unit of this SummarizeExadataInsightResourceUsageCollection.
        :type: str
        """
        allowed_values = ["CORES", "GB", "MBPS", "IOPS", "PERCENT"]
        if not value_allowed_none_or_none_sentinel(usage_unit, allowed_values):
            usage_unit = 'UNKNOWN_ENUM_VALUE'
        self._usage_unit = usage_unit

    @property
    def items(self):
        """
        **[Required]** Gets the items of this SummarizeExadataInsightResourceUsageCollection.
        Collection of Resource Usage Summary items


        :return: The items of this SummarizeExadataInsightResourceUsageCollection.
        :rtype: list[oci.opsi.models.ResourceUsageSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this SummarizeExadataInsightResourceUsageCollection.
        Collection of Resource Usage Summary items


        :param items: The items of this SummarizeExadataInsightResourceUsageCollection.
        :type: list[oci.opsi.models.ResourceUsageSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Type(object):
    """
    DataAsset & Connection Registry Attributes
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Type object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_asset_attributes:
            The value to assign to the data_asset_attributes property of this Type.
        :type data_asset_attributes: list[oci.data_connectivity.models.Attribute]

        :param connection_attributes:
            The value to assign to the connection_attributes property of this Type.
        :type connection_attributes: dict(str, list[Attribute])

        """
        self.swagger_types = {
            'data_asset_attributes': 'list[Attribute]',
            'connection_attributes': 'dict(str, list[Attribute])'
        }

        self.attribute_map = {
            'data_asset_attributes': 'dataAssetAttributes',
            'connection_attributes': 'connectionAttributes'
        }

        self._data_asset_attributes = None
        self._connection_attributes = None

    @property
    def data_asset_attributes(self):
        """
        **[Required]** Gets the data_asset_attributes of this Type.
        list of attributes for the dataAsset


        :return: The data_asset_attributes of this Type.
        :rtype: list[oci.data_connectivity.models.Attribute]
        """
        return self._data_asset_attributes

    @data_asset_attributes.setter
    def data_asset_attributes(self, data_asset_attributes):
        """
        Sets the data_asset_attributes of this Type.
        list of attributes for the dataAsset


        :param data_asset_attributes: The data_asset_attributes of this Type.
        :type: list[oci.data_connectivity.models.Attribute]
        """
        self._data_asset_attributes = data_asset_attributes

    @property
    def connection_attributes(self):
        """
        **[Required]** Gets the connection_attributes of this Type.
        Map of connectionType as key and List of attributes as value


        :return: The connection_attributes of this Type.
        :rtype: dict(str, list[Attribute])
        """
        return self._connection_attributes

    @connection_attributes.setter
    def connection_attributes(self, connection_attributes):
        """
        Sets the connection_attributes of this Type.
        Map of connectionType as key and List of attributes as value


        :param connection_attributes: The connection_attributes of this Type.
        :type: dict(str, list[Attribute])
        """
        self._connection_attributes = connection_attributes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OntologyClass(object):
    """
    Images and ImageObjects can be labeled with an OntologyClass.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OntologyClass object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this OntologyClass.
        :type name: str

        :param parent_names:
            The value to assign to the parent_names property of this OntologyClass.
        :type parent_names: list[str]

        :param synonym_names:
            The value to assign to the synonym_names property of this OntologyClass.
        :type synonym_names: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'parent_names': 'list[str]',
            'synonym_names': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'parent_names': 'parentNames',
            'synonym_names': 'synonymNames'
        }

        self._name = None
        self._parent_names = None
        self._synonym_names = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OntologyClass.
        The label name.


        :return: The name of this OntologyClass.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OntologyClass.
        The label name.


        :param name: The name of this OntologyClass.
        :type: str
        """
        self._name = name

    @property
    def parent_names(self):
        """
        Gets the parent_names of this OntologyClass.
        The label parents.


        :return: The parent_names of this OntologyClass.
        :rtype: list[str]
        """
        return self._parent_names

    @parent_names.setter
    def parent_names(self, parent_names):
        """
        Sets the parent_names of this OntologyClass.
        The label parents.


        :param parent_names: The parent_names of this OntologyClass.
        :type: list[str]
        """
        self._parent_names = parent_names

    @property
    def synonym_names(self):
        """
        Gets the synonym_names of this OntologyClass.
        The label synonyms.


        :return: The synonym_names of this OntologyClass.
        :rtype: list[str]
        """
        return self._synonym_names

    @synonym_names.setter
    def synonym_names(self, synonym_names):
        """
        Sets the synonym_names of this OntologyClass.
        The label synonyms.


        :param synonym_names: The synonym_names of this OntologyClass.
        :type: list[str]
        """
        self._synonym_names = synonym_names

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EnableConditions(object):
    """
    The details of the audit policy provisioning conditions.
    """

    #: A constant which can be used with the entity_selection property of a EnableConditions.
    #: This constant has a value of "INCLUDE"
    ENTITY_SELECTION_INCLUDE = "INCLUDE"

    #: A constant which can be used with the entity_selection property of a EnableConditions.
    #: This constant has a value of "EXCLUDE"
    ENTITY_SELECTION_EXCLUDE = "EXCLUDE"

    #: A constant which can be used with the entity_type property of a EnableConditions.
    #: This constant has a value of "USER"
    ENTITY_TYPE_USER = "USER"

    #: A constant which can be used with the entity_type property of a EnableConditions.
    #: This constant has a value of "ROLE"
    ENTITY_TYPE_ROLE = "ROLE"

    #: A constant which can be used with the entity_type property of a EnableConditions.
    #: This constant has a value of "ALL_USERS"
    ENTITY_TYPE_ALL_USERS = "ALL_USERS"

    #: A constant which can be used with the operation_status property of a EnableConditions.
    #: This constant has a value of "SUCCESS"
    OPERATION_STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the operation_status property of a EnableConditions.
    #: This constant has a value of "FAILURE"
    OPERATION_STATUS_FAILURE = "FAILURE"

    #: A constant which can be used with the operation_status property of a EnableConditions.
    #: This constant has a value of "BOTH"
    OPERATION_STATUS_BOTH = "BOTH"

    def __init__(self, **kwargs):
        """
        Initializes a new EnableConditions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_selection:
            The value to assign to the entity_selection property of this EnableConditions.
            Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_selection: str

        :param entity_type:
            The value to assign to the entity_type property of this EnableConditions.
            Allowed values for this property are: "USER", "ROLE", "ALL_USERS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        :param operation_status:
            The value to assign to the operation_status property of this EnableConditions.
            Allowed values for this property are: "SUCCESS", "FAILURE", "BOTH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_status: str

        :param entity_names:
            The value to assign to the entity_names property of this EnableConditions.
        :type entity_names: list[str]

        """
        self.swagger_types = {
            'entity_selection': 'str',
            'entity_type': 'str',
            'operation_status': 'str',
            'entity_names': 'list[str]'
        }

        self.attribute_map = {
            'entity_selection': 'entitySelection',
            'entity_type': 'entityType',
            'operation_status': 'operationStatus',
            'entity_names': 'entityNames'
        }

        self._entity_selection = None
        self._entity_type = None
        self._operation_status = None
        self._entity_names = None

    @property
    def entity_selection(self):
        """
        **[Required]** Gets the entity_selection of this EnableConditions.
        The entity include or exclude selection.

        Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_selection of this EnableConditions.
        :rtype: str
        """
        return self._entity_selection

    @entity_selection.setter
    def entity_selection(self, entity_selection):
        """
        Sets the entity_selection of this EnableConditions.
        The entity include or exclude selection.


        :param entity_selection: The entity_selection of this EnableConditions.
        :type: str
        """
        allowed_values = ["INCLUDE", "EXCLUDE"]
        if not value_allowed_none_or_none_sentinel(entity_selection, allowed_values):
            entity_selection = 'UNKNOWN_ENUM_VALUE'
        self._entity_selection = entity_selection

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this EnableConditions.
        The entity type that the policy must be enabled for.

        Allowed values for this property are: "USER", "ROLE", "ALL_USERS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_type of this EnableConditions.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this EnableConditions.
        The entity type that the policy must be enabled for.


        :param entity_type: The entity_type of this EnableConditions.
        :type: str
        """
        allowed_values = ["USER", "ROLE", "ALL_USERS"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            entity_type = 'UNKNOWN_ENUM_VALUE'
        self._entity_type = entity_type

    @property
    def operation_status(self):
        """
        **[Required]** Gets the operation_status of this EnableConditions.
        The operation status that the policy must be enabled for.

        Allowed values for this property are: "SUCCESS", "FAILURE", "BOTH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_status of this EnableConditions.
        :rtype: str
        """
        return self._operation_status

    @operation_status.setter
    def operation_status(self, operation_status):
        """
        Sets the operation_status of this EnableConditions.
        The operation status that the policy must be enabled for.


        :param operation_status: The operation_status of this EnableConditions.
        :type: str
        """
        allowed_values = ["SUCCESS", "FAILURE", "BOTH"]
        if not value_allowed_none_or_none_sentinel(operation_status, allowed_values):
            operation_status = 'UNKNOWN_ENUM_VALUE'
        self._operation_status = operation_status

    @property
    def entity_names(self):
        """
        Gets the entity_names of this EnableConditions.
        List of users or roles that the policy must be enabled for.


        :return: The entity_names of this EnableConditions.
        :rtype: list[str]
        """
        return self._entity_names

    @entity_names.setter
    def entity_names(self, entity_names):
        """
        Sets the entity_names of this EnableConditions.
        List of users or roles that the policy must be enabled for.


        :param entity_names: The entity_names of this EnableConditions.
        :type: list[str]
        """
        self._entity_names = entity_names

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SightingSummary(object):
    """
    Sighting summary Definition.
    """

    #: A constant which can be used with the classification_status property of a SightingSummary.
    #: This constant has a value of "FALSE_POSITIVE"
    CLASSIFICATION_STATUS_FALSE_POSITIVE = "FALSE_POSITIVE"

    #: A constant which can be used with the classification_status property of a SightingSummary.
    #: This constant has a value of "FALSE_NEGATIVE"
    CLASSIFICATION_STATUS_FALSE_NEGATIVE = "FALSE_NEGATIVE"

    #: A constant which can be used with the classification_status property of a SightingSummary.
    #: This constant has a value of "TRUE_POSITIVE"
    CLASSIFICATION_STATUS_TRUE_POSITIVE = "TRUE_POSITIVE"

    #: A constant which can be used with the classification_status property of a SightingSummary.
    #: This constant has a value of "TRUE_NEGATIVE"
    CLASSIFICATION_STATUS_TRUE_NEGATIVE = "TRUE_NEGATIVE"

    #: A constant which can be used with the classification_status property of a SightingSummary.
    #: This constant has a value of "NOT_CLASSIFIED"
    CLASSIFICATION_STATUS_NOT_CLASSIFIED = "NOT_CLASSIFIED"

    #: A constant which can be used with the severity property of a SightingSummary.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the severity property of a SightingSummary.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a SightingSummary.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a SightingSummary.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a SightingSummary.
    #: This constant has a value of "MINOR"
    SEVERITY_MINOR = "MINOR"

    #: A constant which can be used with the confidence property of a SightingSummary.
    #: This constant has a value of "CRITICAL"
    CONFIDENCE_CRITICAL = "CRITICAL"

    #: A constant which can be used with the confidence property of a SightingSummary.
    #: This constant has a value of "HIGH"
    CONFIDENCE_HIGH = "HIGH"

    #: A constant which can be used with the confidence property of a SightingSummary.
    #: This constant has a value of "MEDIUM"
    CONFIDENCE_MEDIUM = "MEDIUM"

    #: A constant which can be used with the confidence property of a SightingSummary.
    #: This constant has a value of "LOW"
    CONFIDENCE_LOW = "LOW"

    #: A constant which can be used with the confidence property of a SightingSummary.
    #: This constant has a value of "MINOR"
    CONFIDENCE_MINOR = "MINOR"

    def __init__(self, **kwargs):
        """
        Initializes a new SightingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SightingSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this SightingSummary.
        :type compartment_id: str

        :param problem_id:
            The value to assign to the problem_id property of this SightingSummary.
        :type problem_id: str

        :param actor_principal_id:
            The value to assign to the actor_principal_id property of this SightingSummary.
        :type actor_principal_id: str

        :param actor_principal_name:
            The value to assign to the actor_principal_name property of this SightingSummary.
        :type actor_principal_name: str

        :param actor_principal_type:
            The value to assign to the actor_principal_type property of this SightingSummary.
        :type actor_principal_type: str

        :param detector_rule_id:
            The value to assign to the detector_rule_id property of this SightingSummary.
        :type detector_rule_id: str

        :param classification_status:
            The value to assign to the classification_status property of this SightingSummary.
            Allowed values for this property are: "FALSE_POSITIVE", "FALSE_NEGATIVE", "TRUE_POSITIVE", "TRUE_NEGATIVE", "NOT_CLASSIFIED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type classification_status: str

        :param sighting_type:
            The value to assign to the sighting_type property of this SightingSummary.
        :type sighting_type: str

        :param sighting_type_display_name:
            The value to assign to the sighting_type_display_name property of this SightingSummary.
        :type sighting_type_display_name: str

        :param tactic_name:
            The value to assign to the tactic_name property of this SightingSummary.
        :type tactic_name: str

        :param technique_name:
            The value to assign to the technique_name property of this SightingSummary.
        :type technique_name: str

        :param sighting_score:
            The value to assign to the sighting_score property of this SightingSummary.
        :type sighting_score: int

        :param severity:
            The value to assign to the severity property of this SightingSummary.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param confidence:
            The value to assign to the confidence property of this SightingSummary.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type confidence: str

        :param time_first_detected:
            The value to assign to the time_first_detected property of this SightingSummary.
        :type time_first_detected: datetime

        :param time_last_detected:
            The value to assign to the time_last_detected property of this SightingSummary.
        :type time_last_detected: datetime

        :param regions:
            The value to assign to the regions property of this SightingSummary.
        :type regions: list[str]

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'problem_id': 'str',
            'actor_principal_id': 'str',
            'actor_principal_name': 'str',
            'actor_principal_type': 'str',
            'detector_rule_id': 'str',
            'classification_status': 'str',
            'sighting_type': 'str',
            'sighting_type_display_name': 'str',
            'tactic_name': 'str',
            'technique_name': 'str',
            'sighting_score': 'int',
            'severity': 'str',
            'confidence': 'str',
            'time_first_detected': 'datetime',
            'time_last_detected': 'datetime',
            'regions': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'problem_id': 'problemId',
            'actor_principal_id': 'actorPrincipalId',
            'actor_principal_name': 'actorPrincipalName',
            'actor_principal_type': 'actorPrincipalType',
            'detector_rule_id': 'detectorRuleId',
            'classification_status': 'classificationStatus',
            'sighting_type': 'sightingType',
            'sighting_type_display_name': 'sightingTypeDisplayName',
            'tactic_name': 'tacticName',
            'technique_name': 'techniqueName',
            'sighting_score': 'sightingScore',
            'severity': 'severity',
            'confidence': 'confidence',
            'time_first_detected': 'timeFirstDetected',
            'time_last_detected': 'timeLastDetected',
            'regions': 'regions'
        }

        self._id = None
        self._compartment_id = None
        self._problem_id = None
        self._actor_principal_id = None
        self._actor_principal_name = None
        self._actor_principal_type = None
        self._detector_rule_id = None
        self._classification_status = None
        self._sighting_type = None
        self._sighting_type_display_name = None
        self._tactic_name = None
        self._technique_name = None
        self._sighting_score = None
        self._severity = None
        self._confidence = None
        self._time_first_detected = None
        self._time_last_detected = None
        self._regions = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SightingSummary.
        Unique identifier for finding event


        :return: The id of this SightingSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SightingSummary.
        Unique identifier for finding event


        :param id: The id of this SightingSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SightingSummary.
        Compartment Id where the resource is created


        :return: The compartment_id of this SightingSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SightingSummary.
        Compartment Id where the resource is created


        :param compartment_id: The compartment_id of this SightingSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def problem_id(self):
        """
        Gets the problem_id of this SightingSummary.
        Problem Id to which the Sighting is associated


        :return: The problem_id of this SightingSummary.
        :rtype: str
        """
        return self._problem_id

    @problem_id.setter
    def problem_id(self, problem_id):
        """
        Sets the problem_id of this SightingSummary.
        Problem Id to which the Sighting is associated


        :param problem_id: The problem_id of this SightingSummary.
        :type: str
        """
        self._problem_id = problem_id

    @property
    def actor_principal_id(self):
        """
        Gets the actor_principal_id of this SightingSummary.
        Unique identifier for principal actor


        :return: The actor_principal_id of this SightingSummary.
        :rtype: str
        """
        return self._actor_principal_id

    @actor_principal_id.setter
    def actor_principal_id(self, actor_principal_id):
        """
        Sets the actor_principal_id of this SightingSummary.
        Unique identifier for principal actor


        :param actor_principal_id: The actor_principal_id of this SightingSummary.
        :type: str
        """
        self._actor_principal_id = actor_principal_id

    @property
    def actor_principal_name(self):
        """
        Gets the actor_principal_name of this SightingSummary.
        Name of the principal actor


        :return: The actor_principal_name of this SightingSummary.
        :rtype: str
        """
        return self._actor_principal_name

    @actor_principal_name.setter
    def actor_principal_name(self, actor_principal_name):
        """
        Sets the actor_principal_name of this SightingSummary.
        Name of the principal actor


        :param actor_principal_name: The actor_principal_name of this SightingSummary.
        :type: str
        """
        self._actor_principal_name = actor_principal_name

    @property
    def actor_principal_type(self):
        """
        Gets the actor_principal_type of this SightingSummary.
        Type of the principal actor


        :return: The actor_principal_type of this SightingSummary.
        :rtype: str
        """
        return self._actor_principal_type

    @actor_principal_type.setter
    def actor_principal_type(self, actor_principal_type):
        """
        Sets the actor_principal_type of this SightingSummary.
        Type of the principal actor


        :param actor_principal_type: The actor_principal_type of this SightingSummary.
        :type: str
        """
        self._actor_principal_type = actor_principal_type

    @property
    def detector_rule_id(self):
        """
        **[Required]** Gets the detector_rule_id of this SightingSummary.
        Unique identifier of the rule


        :return: The detector_rule_id of this SightingSummary.
        :rtype: str
        """
        return self._detector_rule_id

    @detector_rule_id.setter
    def detector_rule_id(self, detector_rule_id):
        """
        Sets the detector_rule_id of this SightingSummary.
        Unique identifier of the rule


        :param detector_rule_id: The detector_rule_id of this SightingSummary.
        :type: str
        """
        self._detector_rule_id = detector_rule_id

    @property
    def classification_status(self):
        """
        **[Required]** Gets the classification_status of this SightingSummary.
        ClassificationStatus of the sighting event

        Allowed values for this property are: "FALSE_POSITIVE", "FALSE_NEGATIVE", "TRUE_POSITIVE", "TRUE_NEGATIVE", "NOT_CLASSIFIED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The classification_status of this SightingSummary.
        :rtype: str
        """
        return self._classification_status

    @classification_status.setter
    def classification_status(self, classification_status):
        """
        Sets the classification_status of this SightingSummary.
        ClassificationStatus of the sighting event


        :param classification_status: The classification_status of this SightingSummary.
        :type: str
        """
        allowed_values = ["FALSE_POSITIVE", "FALSE_NEGATIVE", "TRUE_POSITIVE", "TRUE_NEGATIVE", "NOT_CLASSIFIED"]
        if not value_allowed_none_or_none_sentinel(classification_status, allowed_values):
            classification_status = 'UNKNOWN_ENUM_VALUE'
        self._classification_status = classification_status

    @property
    def sighting_type(self):
        """
        **[Required]** Gets the sighting_type of this SightingSummary.
        Identifier for the sighting type


        :return: The sighting_type of this SightingSummary.
        :rtype: str
        """
        return self._sighting_type

    @sighting_type.setter
    def sighting_type(self, sighting_type):
        """
        Sets the sighting_type of this SightingSummary.
        Identifier for the sighting type


        :param sighting_type: The sighting_type of this SightingSummary.
        :type: str
        """
        self._sighting_type = sighting_type

    @property
    def sighting_type_display_name(self):
        """
        **[Required]** Gets the sighting_type_display_name of this SightingSummary.
        Name of the sighting type


        :return: The sighting_type_display_name of this SightingSummary.
        :rtype: str
        """
        return self._sighting_type_display_name

    @sighting_type_display_name.setter
    def sighting_type_display_name(self, sighting_type_display_name):
        """
        Sets the sighting_type_display_name of this SightingSummary.
        Name of the sighting type


        :param sighting_type_display_name: The sighting_type_display_name of this SightingSummary.
        :type: str
        """
        self._sighting_type_display_name = sighting_type_display_name

    @property
    def tactic_name(self):
        """
        **[Required]** Gets the tactic_name of this SightingSummary.
        Name of the Mitre att&ck tactic


        :return: The tactic_name of this SightingSummary.
        :rtype: str
        """
        return self._tactic_name

    @tactic_name.setter
    def tactic_name(self, tactic_name):
        """
        Sets the tactic_name of this SightingSummary.
        Name of the Mitre att&ck tactic


        :param tactic_name: The tactic_name of this SightingSummary.
        :type: str
        """
        self._tactic_name = tactic_name

    @property
    def technique_name(self):
        """
        **[Required]** Gets the technique_name of this SightingSummary.
        Name of the Mitre att&ck technique


        :return: The technique_name of this SightingSummary.
        :rtype: str
        """
        return self._technique_name

    @technique_name.setter
    def technique_name(self, technique_name):
        """
        Sets the technique_name of this SightingSummary.
        Name of the Mitre att&ck technique


        :param technique_name: The technique_name of this SightingSummary.
        :type: str
        """
        self._technique_name = technique_name

    @property
    def sighting_score(self):
        """
        **[Required]** Gets the sighting_score of this SightingSummary.
        Score for the sighting


        :return: The sighting_score of this SightingSummary.
        :rtype: int
        """
        return self._sighting_score

    @sighting_score.setter
    def sighting_score(self, sighting_score):
        """
        Sets the sighting_score of this SightingSummary.
        Score for the sighting


        :param sighting_score: The sighting_score of this SightingSummary.
        :type: int
        """
        self._sighting_score = sighting_score

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this SightingSummary.
        Severity of the sighting

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this SightingSummary.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this SightingSummary.
        Severity of the sighting


        :param severity: The severity of this SightingSummary.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this SightingSummary.
        Confidence of the sighting

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The confidence of this SightingSummary.
        :rtype: str
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this SightingSummary.
        Confidence of the sighting


        :param confidence: The confidence of this SightingSummary.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(confidence, allowed_values):
            confidence = 'UNKNOWN_ENUM_VALUE'
        self._confidence = confidence

    @property
    def time_first_detected(self):
        """
        **[Required]** Gets the time_first_detected of this SightingSummary.
        The date and time the sighting was first detected. Format defined by RFC3339.


        :return: The time_first_detected of this SightingSummary.
        :rtype: datetime
        """
        return self._time_first_detected

    @time_first_detected.setter
    def time_first_detected(self, time_first_detected):
        """
        Sets the time_first_detected of this SightingSummary.
        The date and time the sighting was first detected. Format defined by RFC3339.


        :param time_first_detected: The time_first_detected of this SightingSummary.
        :type: datetime
        """
        self._time_first_detected = time_first_detected

    @property
    def time_last_detected(self):
        """
        **[Required]** Gets the time_last_detected of this SightingSummary.
        The date and time the sighting was last detected. Format defined by RFC3339.


        :return: The time_last_detected of this SightingSummary.
        :rtype: datetime
        """
        return self._time_last_detected

    @time_last_detected.setter
    def time_last_detected(self, time_last_detected):
        """
        Sets the time_last_detected of this SightingSummary.
        The date and time the sighting was last detected. Format defined by RFC3339.


        :param time_last_detected: The time_last_detected of this SightingSummary.
        :type: datetime
        """
        self._time_last_detected = time_last_detected

    @property
    def regions(self):
        """
        **[Required]** Gets the regions of this SightingSummary.
        Regions involved in the sighting


        :return: The regions of this SightingSummary.
        :rtype: list[str]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """
        Sets the regions of this SightingSummary.
        Regions involved in the sighting


        :param regions: The regions of this SightingSummary.
        :type: list[str]
        """
        self._regions = regions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
